@@ -1,4 +1,4 @@
-emve <- function(x, n.resample=100, maxits=5, n.sub.size)
+emve <- function(x, n.resample=500, maxits=3)
 {
 	xcall <- match.call()
 
@@ -8,7 +8,6 @@ emve <- function(x, n.resample=100, maxits=5, n.sub.size)
 	else stop("Data matrix must be of class matrix or data.frame")
 	if( ncol(x) < 2 ) stop("Column dimension of 'x' must be at least 2.")
 
-	
 	## Check number of resampling
 	if( n.resample < 20 ) stop("Number of resampling must be >= 20.")
 
@@ -45,19 +44,13 @@ emve <- function(x, n.resample=100, maxits=5, n.sub.size)
 	S0 <- diag(apply(x_sort$x, 2, var, na.rm=T))
 	x_sort <- c(x_sort, .CovEM.setparam(p, mu0, S0))
 	
-	## Check subsample size
-	if( missing(n.sub.size)) 
-		n.sub.size <- floor( (p+1)/(1-mean(is.na(x))) )+1   #initial sub-sampling size
-	if (n.sub.size <= p) 
-		stop("n.sub.size <= p -- you can't be serious!")
-			
+	n.sub.size <- floor( (p+1)/(1-mean(is.na(x))) )
 	res <- with(x_sort, .emve.init(x, x_nonmiss, pu, n, p, theta, G.ind-1, length(theta),x.miss.group.match,
 		miss.group.unique, miss.group.counts, miss.group.obs.col, miss.group.mis.col, 
 		miss.group.p, miss.group.n, n.resample, maxits, n.sub.size))
 
-
 	S.chol <- tryCatch( chol(res$S), error=function(e) NA)
-	if( !is.matrix(S.chol) )  warning("Estimated covariance matrix is not positive definite. May consider increase the sample size of the data.")		
+	if( !is.matrix(S.chol) )  stop("Estimated covariance matrix is not positive definite.")
 
 	pmd <- pmd.adj <- rep(NA, nrow(x_orig))
 	pmd[ok] <- res$pmd[x_sort$id.ro]
@@ -68,9 +61,6 @@ emve <- function(x, n.resample=100, maxits=5, n.sub.size)
 		S = res$S,
 		mu = res$mu,
 		sc=res$mve.scale,
-		cand.sc=res$cand.mve.scale,
-		cand.mu=res$cand.mu,
-		cand.S=res$cand.Sigma,
 		estimator = "Extended Minimum Volume Ellipsoid", 
 		x = x_orig,
 		pmd = pmd,
@@ -78,22 +68,15 @@ emve <- function(x, n.resample=100, maxits=5, n.sub.size)
 		p = p, 
 		pu = pu)
 }
-	
-	
-	
-	
+
+
 ## Assume the input data matrix is sorted using .sort.missing
 .emve.init <- function(x, x_nonmiss, pu, n, p, theta0, G, d, x.miss.group.match, miss.group.unique, miss.group.counts, 
-	miss.group.obs.col, miss.group.mis.col, miss.group.p, miss.group.n, n.resample=100, maxits=5, n.sub.size)
+	miss.group.obs.col, miss.group.mis.col, miss.group.p, miss.group.n, n.resample=500, maxits=5, n.sub.size)
 {
-	##########################################################################################
-	## SOME VARIABLE SETUP
-	## Check subsample size
-	if( missing(n.sub.size)) 
-		n.sub.size <- floor( (p+1)/(1-mean(is.na(x))) )+1   #initial sub-sampling size
-	if (n.sub.size <= p) 
-		stop("n.sub.size <= p -- you can't be serious!")
-		
+	if(missing(n.sub.size))
+		n.sub.size <- floor( (p+1)/(1-mean(is.na(x))) )
+
 	## Initial scales for later calculation
 	scale0_init <- .scale.mve.init(pu)  # will be used to calculate EMVE scale
 	cc <- scale0_init$cc
@@ -105,19 +88,13 @@ emve <- function(x, n.resample=100, maxits=5, n.sub.size)
 	a <- is.na(x)%*%diag(colmed)
 	x_filled[is.na(x_filled)] <- 0
 	x_filled <- x_filled + a
-	##########################################################################################
 	
 	res <- .emve.Rcpp(x_filled, x_nonmiss, pu, n, p, theta0, G, d, x.miss.group.match, miss.group.unique, miss.group.counts,
-			miss.group.obs.col, miss.group.mis.col, miss.group.p, miss.group.n, n.resample, n.sub.size, 0.00001, cc, ck, maxits)
-
-	## only the best 10 candidates
+			miss.group.obs.col, miss.group.mis.col, miss.group.p, miss.group.n, n.resample, n.sub.size, 1e-7, cc, ck, maxits)
 	res <- list(
-		S = res$S0[,,1],
-		mu = res$mu0[1,],
-		mve.scale=res$ss0[1],
-		cand.mve.scale=res$ss0[1:10],
-		cand.mu=res$mu0[1:10,],
-		cand.Sigma=res$S0[,,1:10])
+		S = res$S0,
+		mu = res$mu0,
+		mve.scale=res$ss0)
 		
 	x.tmp <- sweep(x, 2, res$mu, "-")	
 	pmd <- .partial.mahalanobis.Rcpp(x.tmp, res$S, miss.group.unique, miss.group.counts)
@@ -126,6 +103,12 @@ emve <- function(x, n.resample=100, maxits=5, n.sub.size)
 	pmd.adj <- qchisq( pchisq( pmd, df=pu, log.p=T, lower.tail=F), df=p, log.p=T, lower.tail=F) 
 	pmd.adj[ which( pu == p)] <- pmd[ which(pu==p) ]
 
+	## size adjust
+	cf <- median( pmd.adj )/qchisq(0.5, df=p)
+	res$S <- cf * res$S
+	pmd <- pmd / cf
+	pmd.adj <- pmd.adj / cf
+	
 	res$pmd <- pmd
 	res$pmd.adj <- pmd.adj
 	res
